@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import unittest
+import responses
 
 from redcap import RCRequest, RCAPIError
 
@@ -37,9 +38,30 @@ class TestClass(unittest.TestCase):
         r = RCRequest(*ags)
         self.assertIsInstance(r, RCRequest)
 
+    @responses.activate
     def test_bad_md(self):
         """Test that newlines are appropriately dealt with"""
+
+        responses.add(responses.POST, 'https://redcap.vanderbilt.edu/api/')
+
         args = ['https://redcap.vanderbilt.edu/api/', self.badmd, 'metadata']
         r = RCRequest(*args).execute()
         self.assertTrue(r is not None)
         self.assertTrue(len(r) > 0)
+
+    def test_survey_participant_list_type(self):
+        payload = {
+            'token': 'foobar',
+            'content': 'participantList',
+            'format': 'json',
+            'instrument': 'bar',
+        }
+        url = 'https://foobarbat.com'
+        typee = 'exp_survey_participant_list'
+        # This should not raise
+        RCRequest(url, payload, typee)
+
+        # This should raise because of a different content
+        payload['content'] = 'foobar'
+        with self.assertRaises(RCAPIError):
+            RCRequest(url, payload, typee)
